# The geolite databases were traditionally updated on the first Tuesday of each month.
# hence we use a versioning scheme of YYYY.MM for the %{_real_vendor} package.
# No further releases of IPv4 GeoLite Legacy databases will be made from April 2018.
# See https://support.maxmind.com/geolite-legacy-discontinuation-notice/
# IPv6 databases were updated in October 2018.
#
# Update this date to fetch new version of the geoip database files
%define dat_date 2018.10

%define oname GeoIP

%define major 1
%define libname %mklibname geoip %{major}
%define develname %mklibname geoip -d

Summary:	Find what country an IP address or hostname originates from
Name:		geoip
Version:	1.6.12
Release:	%mkrel 5
License:	LGPLv2+
Group:		System/Libraries
URL:		http://dev.maxmind.com/geoip/
Source0:	https://github.com/maxmind/geoip-api-c/releases/download/v%{version}/%{oname}-%{version}.tar.gz
Source1:	http://geolite.maxmind.com/download/geoip/database/GeoLiteCountry/%{oname}.dat.gz#/%{oname}-%{dat_date}.dat.gz
Source2:	http://geolite.maxmind.com/download/geoip/database/LICENSE.txt
Source3:	http://geolite.maxmind.com/download/geoip/database/GeoLiteCity.dat.xz#/GeoLiteCity-%{dat_date}.dat.xz
Source4:	http://geolite.maxmind.com/download/geoip/database/asnum/GeoIPASNum.dat.gz#/GeoIPASNum-%{dat_date}.dat.gz
Source5:	http://geolite.maxmind.com/download/geoip/database/GeoIPv6.dat.gz#/GeoIPv6-%{dat_date}.dat.gz
Source6:	http://geolite.maxmind.com/download/geoip/database/GeoLiteCityv6-beta/GeoLiteCityv6.dat.gz#/GeoLiteCityv6-%{dat_date}.dat.gz
Source7:	http://download.maxmind.com/download/geoip/database/asnum/GeoIPASNumv6.dat.gz#/GeoIPASNumv6-%{dat_date}.dat.gz
BuildRequires:	pkgconfig(zlib)
Requires:	%{name}-database >= %{version}

%description
GeoIP is a C library that enables the user to find the country that any IP
address or hostname originates from. It uses a file based database that is
accurate as of March 2003. This database simply contains IP blocks as keys,
and countries as values. This database should be more complete and accurate
than using reverse DNS lookups. Commercial databases and automatic update
services are available from http://www.maxmind.com/

This module can be used to automatically select the geographically closest
mirror, to analyze your web server logs to determine the countries of your
visitors, for credit card fraud detection, and for software export controls.

%package -n	%{libname}
Summary:	Shared library part of GeoIP
Group:		System/Libraries
Requires:	%{name}-database >= %{version}

%description -n	%{libname}
GeoIP is a C library that enables the user to find the country that any IP
address or hostname originates from. It uses a file based database that is
accurate as of March 2003. This database simply contains IP blocks as keys,
and countries as values. This database should be more complete and accurate
than using reverse DNS lookups. Commercial databases and automatic update
services are available from http://www.maxmind.com/

This module can be used to automatically select the geographically closest
mirror, to analyze your web server logs to determine the countries of your
visitors, for credit card fraud detection, and for software export controls.

%package -n	%{develname}
Summary:	Headers and libraries needed for GeoIP development
Group:		Development/C
Requires:	%{libname} = %{version}
Provides:	%{name}-devel = %{version}
Provides:	%{oname}-devel = %{version}
Obsoletes:	%{mklibname geoip 1 -d}

%description -n	%{develname}
GeoIP is a C library that enables the user to find the country that any IP
address or hostname originates from. It uses a file based database that is
accurate as of March 2003. This database simply contains IP blocks as keys,
and countries as values. This database should be more complete and accurate
than using reverse DNS lookups. Commercial databases and automatic update
services are available from http://www.maxmind.com/

This module can be used to automatically select the geographically closest
mirror, to analyze your web server logs to determine the countries of your
visitors, for credit card fraud detection, and for software export controls.

%package	database
Summary:	Free (GeoLite) IP geolocation databases for GeoIP
Group:		Networking/Other
License:	CC-BY-SA
BuildArch:	noarch
Conflicts:	%{name} < 1.5.1-2

%description	database
This package contains the free (GeoLite) IP geolocation databases for GeoIP.


%prep
%setup -q -n %{oname}-%{version}

zcat %{SOURCE1} > data/GeoIP.dat
cp   %{SOURCE2} LICENSE.txt
xzcat %{SOURCE3} > data/GeoLiteCity.dat
zcat %{SOURCE4} > data/GeoIPASNum.dat
zcat %{SOURCE5} > data/GeoIPv6.dat
zcat %{SOURCE6} > data/GeoLiteCityv6.dat
zcat %{SOURCE7} > data/GeoIPASNumv6.dat

%build
autoreconf -fi
%configure --disable-static
%make_build

%install
%make_install
mkdir -p %{buildroot}%{_sysconfdir}/cron.monthly
mkdir -p %{buildroot}%{_datadir}/GeoIP
install -m0644 data/*.dat %{buildroot}%{_datadir}/GeoIP/

# don't ship .la
find %{buildroot} -name '*.la' -exec rm -f '{}' \;

%files
%doc AUTHORS COPYING ChangeLog README.md LICENSE.txt
%{_bindir}/geoiplookup
%{_bindir}/geoiplookup6
%{_mandir}/man1/geoiplookup.1*
%{_mandir}/man1/geoiplookup6.1*

%files -n %{libname}
%{_libdir}/libGeoIP.so.%{major}{,.*}

%files -n %{develname}
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/*

%files database
%{_datadir}/GeoIP/


%changelog
* Fri Feb 14 2020 umeabot <umeabot> 1.6.12-5.mga8
+ Revision: 1517717
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Oct 02 2018 wally <wally> 1.6.12-4.mga7
+ Revision: 1315203
- update IPv6 databases to October 2018 version
- upstream doesn't provide updates for IPv4 databases anymore

* Sun Sep 23 2018 umeabot <umeabot> 1.6.12-3.mga7
+ Revision: 1297861
- Mageia 7 Mass Rebuild

* Tue Jun 19 2018 wally <wally> 1.6.12-2.mga7
+ Revision: 1238169
- drop check as tests will fail with updated database files
+ kekepower <kekepower>
- Add date to file names on the dat files

* Wed Apr 11 2018 kekepower <kekepower> 1.6.12-1.mga7
+ Revision: 1217401
- Update to version 1.6.12
- Update geoip database files
+ luigiwalser <luigiwalser>
- 1.6.11
- update geoip databases
- 1.6.10
- update geoip databases

* Wed Mar 23 2016 dlucio <dlucio> 1.6.9-2.mga6
+ Revision: 994237
- %%make_install instead of %%makeinstall

* Mon Jan 25 2016 luigiwalser <luigiwalser> 1.6.9-1.mga6
+ Revision: 927141
- 1.6.9
- update geoip databases

* Fri Dec 18 2015 oden <oden> 1.6.7-1.mga6
+ Revision: 911624
- update sources
- 1.6.7

* Wed Apr 15 2015 luigiwalser <luigiwalser> 1.6.5-1.mga5
+ Revision: 820287
- 1.6.5
- update geoip databases

* Tue Jan 27 2015 luigiwalser <luigiwalser> 1.6.4-1.mga5
+ Revision: 812458
- 1.6.4
- update geoip ASNum databases

* Fri Jan 09 2015 luigiwalser <luigiwalser> 1.6.3-2.mga5
+ Revision: 809534
- update geoip databases

* Tue Nov 04 2014 luigiwalser <luigiwalser> 1.6.3-1.mga5
+ Revision: 795536
- 1.6.3

* Tue Nov 04 2014 oden <oden> 1.6.2-4.mga5
+ Revision: 795494
- update the database files and add two more; GeoLiteCityv6.dat and GeoIPASNumv6.dat

* Wed Oct 15 2014 umeabot <umeabot> 1.6.2-3.mga5
+ Revision: 748669
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.6.2-2.mga5
+ Revision: 679503
- Mageia 5 Mass Rebuild

* Fri Jul 11 2014 luigiwalser <luigiwalser> 1.6.2-1.mga5
+ Revision: 651170
- 1.6.2

* Wed Jul 02 2014 luigiwalser <luigiwalser> 1.6.1-1.mga5
+ Revision: 642327
- 1.6.1
- update source URL
- update databases

* Mon Feb 24 2014 pterjan <pterjan> 1.6.0-2.mga5
+ Revision: 596469
- Copy all the .dat files, fixing the missing GeoIP.dat

* Fri Feb 21 2014 luigiwalser <luigiwalser> 1.6.0-1.mga5
+ Revision: 595321
- 1.6.0
- update GeoIP databases
- remove geoipupdate library subpackage (no longer exists)
- remove geoipupdate from files list (no longer exists)
- remove configuration files (no longer exist)
- remove awful cron job

* Sat Oct 19 2013 umeabot <umeabot> 1.5.1-3.mga4
+ Revision: 532948
- Mageia 4 Mass Rebuild

* Fri Aug 23 2013 wally <wally> 1.5.1-2.mga4
+ Revision: 470404
- make libs to require database pkg instead of main pkg
- split out databases to own pkg
- update databases

* Sun Jun 09 2013 fwang <fwang> 1.5.1-1.mga4
+ Revision: 441077
- update file list
- new version 1.5.1

* Fri Jan 11 2013 umeabot <umeabot> 1.4.8-5.mga3
+ Revision: 351375
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ dams <dams>
- clean specfile

* Wed Nov 23 2011 pterjan <pterjan> 1.4.8-4.mga2
+ Revision: 171462
- Add IPv6 database (needed by ipv6calc)
- Fix cron filename

* Fri Nov 18 2011 pterjan <pterjan> 1.4.8-3.mga2
+ Revision: 168857
- Update date

* Mon Jul 18 2011 ahmad <ahmad> 1.4.8-2.mga2
+ Revision: 125844
- Rebuild after refreshing all the other Sources tarballs

* Mon Jul 18 2011 ahmad <ahmad> 1.4.8-1.mga2
+ Revision: 125839
- Replace the lib%%{name}-devel provides with %%{name}-devel
- Update to 1.4.8
- Convert the BR to pkgconfig style
- Fix the build by running 'autoreconf -fi'

* Wed Apr 27 2011 ahmad <ahmad> 1.4.7-1.mga1
+ Revision: 92191
- Don't flag %%{_datadir}/GeoIP as a %%config, it contains .dat files only, no configuration
  files AFAICS
- Update to 1.4.7
- Get new SOURCES 1,3,4 binaries:
  o this way we don't overwrite %%{_datadir}/GeoIP/GeoIP.dat that's updated by the
    monthly cron job
- Drop the autoconf hack, the package builds finely without it
- Drop BR libtool, not needed now AFAICS
- Disable static build (and don't ship .la)

* Sun Jan 16 2011 ahmad <ahmad> 1.4.6-9.mga1
+ Revision: 19934
- drop old/uneeded scriptlest
- change the ping command to use svn.mageia.org
+ kharec <kharec>
- imported package geoip


* Sun Aug 01 2010 Funda Wang <fwang@mandriva.org> 1.4.6-8mdv2011.0
+ Revision: 564253
- rebuild for perl 5.12.1

  + Sandro Cazzaniga <kharec@mandriva.org>
    - fix Source1

* Thu Feb 18 2010 Götz Waschk <waschk@mandriva.org> 1.4.6-6mdv2010.1
+ Revision: 507920
- use the right file for the cron job

* Thu Feb 18 2010 Luis Daniel Lucio Quiroz <dlucio@mandriva.org> 1.4.6-5mdv2010.1
+ Revision: 507900
- New monthly crontab that lets update to non-payed suscriptors
- DataBase update to 20100201

* Wed Sep 09 2009 Oden Eriksson <oeriksson@mandriva.com> 1.4.6-2mdv2010.0
+ Revision: 435105
- added some additional data files

* Tue Mar 17 2009 Götz Waschk <waschk@mandriva.org> 1.4.6-1mdv2009.1
+ Revision: 356530
- new version
- update file list
- update license

* Fri Oct 17 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.4.5-1mdv2009.1
+ Revision: 294777
- new version

* Fri Jun 13 2008 Oden Eriksson <oeriksson@mandriva.com> 1.4.4-3mdv2009.0
+ Revision: 218736
- new database

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Sat May 10 2008 Oden Eriksson <oeriksson@mandriva.com> 1.4.4-2mdv2009.0
+ Revision: 205387
- new database

* Mon Feb 04 2008 Oden Eriksson <oeriksson@mandriva.com> 1.4.4-1mdv2008.1
+ Revision: 162379
- 1.4.4
- newer database

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Sep 03 2007 Oden Eriksson <oeriksson@mandriva.com> 1.4.3-1mdv2008.0
+ Revision: 78623
- 1.4.3

  + Thierry Vignaud <tv@mandriva.org>
    - replace %%{_datadir}/man by %%{_mandir}!


* Wed Jan 17 2007 Götz Waschk <waschk@mandriva.org> 1.4.1-3mdv2007.0
+ Revision: 109845
- fix man page
- fix check

* Wed Jan 17 2007 Götz Waschk <waschk@mandriva.org> 1.4.1-2mdv2007.1
+ Revision: 109777
- add missing data file (bug #28257)

* Mon Jan 08 2007 Oden Eriksson <oeriksson@mandriva.com> 1.4.1-1mdv2007.1
+ Revision: 106089
- 1.4.1
- drop the upstream update vulnerability patch

* Fri Jan 05 2007 Oden Eriksson <oeriksson@mandriva.com> 1.4.0-3mdv2007.1
+ Revision: 104548
- plug a sec hole (P0)
- rebuild
- Import geoip

* Tue Aug 29 2006 Götz Waschk <waschk@mandriva.org> 1.4.0-2mdv2007.0
- spec fix

* Thu Aug 24 2006 Oden Eriksson <oeriksson@mandriva.com> 1.4.0-1mdv2007.0
- 1.4.0
- new S1

* Fri Jul 28 2006 Oden Eriksson <oeriksson@mandriva.com> 1.3.17-1mdv2007.0
- 1.3.17
- new S1

* Fri Jul 21 2006 Götz Waschk <waschk@mandriva.org> 1.3.8-4mdk
- Rebuild

* Mon Jan 16 2006 Götz Waschk <waschk@mandriva.org> 1.3.8-3mdk
- fix build without network

* Tue Jan 03 2006 Götz Waschk <waschk@mandriva.org> 1.3.8-2mdk
- Rebuild
- use mkrel

* Sun Jan 02 2005 Frederic Lepied <flepied@mandrakesoft.com> 1.3.8-1mdk
- New release 1.3.8

* Tue Sep 28 2004 Frederic Lepied <flepied@mandrakesoft.com> 1.3.6-2mdk
- updated data

* Wed Aug 18 2004 Frederic Lepied <flepied@mandrakesoft.com> 1.3.6-1mdk
- New release 1.3.6

* Tue May 11 2004 Goetz Waschk <waschk@linux-mandrake.com> 1.3.2-1mdk
- New release 1.3.2

* Thu Feb 19 2004 Götz Waschk <waschk@linux-mandrake.com> 1.3.1-1mdk
- new version

